@@ -9,11 +9,9 @@ import org.snpeff.SnpEff;
 import org.snpeff.fileIterator.VcfFileIterator;
 import org.snpeff.snpEffect.Config;
 import org.snpeff.snpEffect.VcfAnnotator;
-import org.snpeff.snpEffect.commandLine.CommandLine;
 import org.snpeff.util.Download;
 import org.snpeff.util.Gpr;
 import org.snpeff.util.Log;
-import org.snpeff.util.Timer;
 import org.snpeff.vcf.VcfEntry;
 import org.snpeff.vcf.VcfHeaderEntry;
 import org.snpsift.caseControl.SnpSiftCmdCaseControlSummary;
@@ -24,7 +22,7 @@ import org.snpsift.hwe.SnpSiftCmdHwe;
  *
  * @author pablocingolani
  */
-public class SnpSift implements VcfAnnotator, CommandLine {
+public class SnpSift implements VcfAnnotator {
 
 	// Version info (in sync with SnpEff)
 	public static final String BUILD = SnpEff.BUILD;
@@ -90,8 +88,9 @@ public class SnpSift implements VcfAnnotator, CommandLine {
 	 */
 	@Override
 	public boolean addHeaders(VcfFileIterator vcfFile) {
-		for (VcfHeaderEntry hinf : headers())
+		for (VcfHeaderEntry hinf : headers()) {
 			vcfFile.getVcfHeader().add(hinf);
+		}
 
 		return false;
 	}
@@ -157,6 +156,10 @@ public class SnpSift implements VcfAnnotator, CommandLine {
 		case "annotate":
 			return new SnpSiftCmdAnnotate();
 
+		case "annmem":
+		case "annotatemem":
+			return new SnpSiftCmdAnnotateDf();
+	
 		case "ca":
 		case "casecontrol":
 			return new SnpSiftCmdCaseControl();
@@ -700,6 +703,7 @@ public class SnpSift implements VcfAnnotator, CommandLine {
 				+ "\nCommand is one of:" //
 				+ "\n\talleleMat     : Create an allele matrix output." //
 				+ "\n\tannotate      : Annotate 'ID' from a database (e.g. dbSnp). Assumes entries are sorted." //
+				+ "\n\tannotateMem   : Annotate form a database (created from a VCF file)." //
 				+ "\n\tcaseControl   : Compare how many variants are in 'case' and in 'control' groups; calculate p-values." //
 				+ "\n\tccs           : Case control summary. Case and control summaries by region, allele frequency and variant's functional effect." //
 				+ "\n\tconcordance   : Concordance metrics between two VCF files." //
